<?php
/*
Plugin Name: EngageBay LiveChat
Plugin URI: https://www.engagebay.com/service/free-live-chat-software
Description: EngageBay LiveChat is the simplest and quickest way to build simple, stylish and responsive forms. Capture leads, grow email lists and dramatically improve conversions using our forms.
Version: 1.1.2
Tested up to: 6.3
Author: EngageBay
Author URI: https://www.engagebay.com
Developer: EngageBay
Developer URL: https://www.engagebay.com
License: GPL2
*/

if (!defined('ABSPATH')) {
    exit('You are not allowed to access this file directly.');
}

function engagebay_livechat_add_new_menu_items()
{
    add_menu_page('Live Chat', 'Live Chat', 'administrator', 'engage-bay-livechat', 'engagebay_livechat_options_page', plugins_url('engagebay-livechat/images/icon.png'), 0);
}

// Register style sheet.
add_action('wp_enqueue_styles', 'engagebay_livechat_css');
/**
 * Register style sheet.
 */
function engagebay_livechat_custom_js()
{
    wp_enqueue_script('custom_script', plugins_url('/js/pubnub.js', __FILE__), array('jquery'));
}

function engagebay_livechat_css()
{
    wp_enqueue_style('engagebay-forms', plugins_url('/css/style.css', __FILE__));
}

add_action( 'plugins_loaded', 'engagebay_livechat_plugin_override' );
function engagebay_livechat_plugin_override() {
  if(isset($_GET['code'])) {
    require_once 'vendor/autoload.php';
  
    $provider = new \League\OAuth2\Client\Provider\GenericProvider([
      'clientId'                => '765095083631-uo5n5br03hl68ora8oohooeu6j0n1dkv.apps.googleusercontent.com',    // The client ID assigned to you by the provider
      'clientSecret'            => 'zAqrJN80mWUKhD5soIZk95u6',   // The client password assigned to you by the provider
      'redirectUri'             => 'https://app.engagebay.com/oauth2callback',
      'urlAuthorize'            => 'https://accounts.google.com/o/oauth2/auth',
      'urlAccessToken'          => 'https://www.googleapis.com/oauth2/v4/token',
      'urlResourceOwnerDetails' => 'https://www.googleapis.com/oauth2/v3/userinfo',
      'scopes' => 'email,profile'
    ]);
    
    try {    
      // Try to get an access token using the authorization code grant.
      $accessToken = $provider->getAccessToken('authorization_code', [
          'code' => $_GET['code']
      ]);
    
      $resourceOwner = $provider->getResourceOwner($accessToken);
    
      $user = $resourceOwner->toArray();
    
      $api_url = 'https://app.engagebay.com//dev/api/panel/api';
      $response = wp_remote_get($api_url,
                 array('timeout' => 40,
                        'method' => 'GET',
                    'sslverify' => true,
                    'headers' => array('Authorization' => 'EngageBayDevAPI!@#', 'ebwhitelist' => true, 'Accept' => 'application/json;ver=1.0', 'Content-Type' => 'application/json; charset=UTF-8', 'email' => $user['email']),
                 ));
  
  
      if (version_compare(PHP_VERSION, '5.4.0', '>=') && !(defined('JSON_C_VERSION') && PHP_INT_SIZE > 4)) {
          $result = json_decode($response['body'], false, 512, JSON_BIGINT_AS_STRING);
      } else {
          $result = json_decode($response['body'], false);
      }
  
      if($result && $result->rest_API_Key) {
        if (get_option('engagebay_livechat_rest_api') !== false) {
          update_option('engagebay_livechat_rest_api', $result->rest_API_Key);
        } else {
            add_option('engagebay_livechat_rest_api', $result->rest_API_Key);
        }
  
        $domain = explode(".",$result->version_url)[0];
        $domain = str_replace("https://", "", $domain);
  
        if (get_option('engagebay_livechat_domain') !== false) {
            update_option('engagebay_livechat_domain', $domain);
        } else {
            add_option('engagebay_domain', $domain);
        }
  
        if (get_option('engagebay_livechat_js_api') !== false) {
            update_option('engagebay_livechat_js_api', $result->js_API_Key);
        } else {
            add_option('engagebay_livechat_js_api', $result->js_API_Key);
        }
  
        if (get_option('engagebay_livechat_email') !== false) {
            update_option('engagebay_livechat_email', $user['email']);
        } else {
            add_option('engagebay_livechat_email', $user['email']);
        }
      }
    
    } catch (\League\OAuth2\Client\Provider\Exception\IdentityProviderException $e) {
    
      // Failed to get the access token or user details.
      exit($e->getMessage());
    
    }
  }
}

function engagebay_livechat_options_page()
{
    engagebay_livechat_css(); ?>
        <div class="wrap">
          <?php
          $rest_api = (sanitize_text_field(get_option('engagebay_livechat_rest_api')));
    if ($rest_api) {
        ?>
       <div id="engagebaywrapper" class="textaligncenter">
<?php echo "<img src='".plugins_url('/images/engagebay.png', __FILE__)."'  title='Engage Bay logo' class='logo'/>"; ?> </div> 
<?php
    }
    $rest_api = (sanitize_text_field(get_option('engagebay_livechat_rest_api')));
    do_settings_sections('engage-bay-livechat'); ?>          
    </div>
    <?php
}

add_action('admin_menu', 'engagebay_livechat_add_new_menu_items');

add_action('admin_init', 'engagebay_livechat_display_options');
function engagebay_livechat_display_options()
{
    add_settings_section('home', '', 'engagebay_livechat_display_header_options_content', 'engage-bay-livechat');
    if (isset($_GET['tab'])) {
        if ($_GET['tab'] == 'register') {
            add_settings_section('livechat_advertising_code', '', 'engagebay_livechat_registration_page', 'engage-bay-livechat', 'home');
        } else {
            add_settings_section('livechat_advertising_code', '', 'engagebay_livechat_settings_page', 'engage-bay-livechat', 'home');
        }
    } else {
        add_settings_section('header_logo', '', 'engagebay_livechat_dashboard_page', 'engage-bay-livechat', 'home');
    }
}

function engagebay_livechat_display_header_options_content()
{
    // echo 'The header of the theme';
}

function engagebay_livechat_dashboard_page()
{
    engagebay_livechat_css();
    $rest_api = (sanitize_text_field(get_option('engagebay_livechat_rest_api')));
    $domain = (sanitize_text_field(get_option('engagebay_livechat_domain')));
    $email = (sanitize_email(get_option('engagebay_livechat_email')));
    if (empty($email)) {
        wp_redirect(engagebay_livechat_settings_page());
    } else {
        ?>
<div id="features">
<a href="https://<?=$domain; ?>.engagebay.com/#chats" id="boxm" target="_blank">
   <div class="box">
   <div class="right stripline">
   <div class="header"><?php echo "<img src='".plugins_url('/images/conversations.svg', __FILE__)."' width='100px' height='100px' title='Answer Chats'/>"; ?> </div>
   <div class="left">
   </div>
   <h2 class="heading">Answer Chats</h2>
   <p>If your customers require any assistance, help them instantly by answering the live chat.<br/><br/></p>
   <span class="anchor more">More</span>
 </div>
</div> </a>
<a href="https://<?=$domain; ?>.engagebay.com/#lc-widget-settings" id="boxm" target="_blank">
<div class="box">
  <div class="right stripline">
    <div class="header">
	<?php echo "<img src='".plugins_url('/images/chat-widgets.svg', __FILE__)."' width='100px' height='100px' title='Chat Widgets'/>"; ?> </div>
    <div class="left">
    </div>
    <h2 class="heading">Chat Widget</h2>
   <p>Customize your chat button by aligning it per your website color scheme and also customize the greetings message.</p>
   <span class="anchor more">More</span>
   </div> 
 </div></a>
 <a href="https://<?=$domain; ?>.engagebay.com/#lc-chat-forms/prechat" id="boxm" target="_blank">
<div class="box">
  <div class="right stripline">
   <div class="header"><?php echo "<img src='".plugins_url('/images/chat-forms.svg', __FILE__)."' width='100px' height='100px' title='Chat Forms'/>"; ?> </div>
   <h2 class="heading">
    Chat Form</h2>
   <p>Customize online & offline chat forms. You can add or remove fields from the chat window.<br/><br/></p>
   <span class="anchor more">More</span>
  </div>
</div></a><br/>
<a href="https://<?=$domain; ?>.engagebay.com/#lc-shortcuts" id="boxm" target="_blank">
  <div class="box">
   <div class="right stripline">
    <div class="header"><?php echo "<img src='".plugins_url('/images/shortcuts.svg', __FILE__)."' width='100px' height='100px' title='Shortcuts'/>"; ?></div>
    <div class="left">
    </div>
    <h2 class="heading">Shortcuts</h2>
    <p>You can create or update unlimited shortcuts to provide quick responses to your customers.</p>
    <span class="anchor more">More</span>
   </div>
</div> </a>
<a href="https://<?=$domain; ?>.engagebay.com/#lc-sound-settings" id="boxm" target="_blank">
  <div class="box">
   <div class="right stripline">
    <div class="header"><?php echo "<img src='".plugins_url('/images/settings.svg', __FILE__)."' width='100px' height='100px' title='Settings'/>"; ?></div>
    <div class="left">
    </div>
    <h2 class="heading">Settings</h2>
    <p>You can set up sound notifications and message notifications to help them get your attention.</p>
    <span class="anchor more">More</span>
   </div>
</div> </a>
<a href="https://<?=$domain; ?>.engagebay.com/#livechat" id="boxm" target="_blank">
  <div class="box">
   <div class="right stripline">
    <div class="header"><?php echo "<img src='".plugins_url('/images/reports.svg', __FILE__)."' width='100px' height='100px' title='Reports'/>"; ?></div>
    <div class="left">
    </div>
    <h2 class="heading">Reports</h2>
    <p>Get a complete overview of your customer queries, chats by country and agents' performance.</p>
    <span class="anchor more">More</span>
   </div>
</div> </a>

</div>
<?php
    }
}

function engagebay_livechat_settings_page()
{
    if (!current_user_can('install_plugins') && !current_user_can('install_plugins')) {
        return;
    }
    engagebay_livechat_css();
    $deprecated = null;
    $autoload = 'no';
    if (isset($_POST['email'])) {
        $email = sanitize_email($_POST['email']);
    }
    if (isset($email) && check_admin_referer('engagebay_livechat_nonce_action', 'engagebay_livechat_nonce_field')) {
        $email = sanitize_email($_POST['email']);
        // $rest_api = sanitize_text_field($_POST['rest_api']);
        $password = sanitize_text_field($_POST['password']);
        $api_url = 'https://app.engagebay.com/rest/api/login/get-domain';
        $request = wp_remote_post($api_url, array(
                'method' => 'post',
                'body' => array('email' => $email, 'password' => $password, 'source' => 'WORDPRESS'),
                'headers' => array('ebwhitelist' => true)
                 )
        );
        $result = wp_remote_retrieve_body($request);
        if (!is_wp_error($result)) {
            if (version_compare(PHP_VERSION, '5.4.0', '>=') && !(defined('JSON_C_VERSION') && PHP_INT_SIZE > 4)) {
                $result = json_decode($result, true, 512, JSON_BIGINT_AS_STRING);
            } else {
                $result = json_decode($result, true);
            }
        }

        if (isset($result['type']) && $result['type'] == 'ACCOUNT_NOT_ACTIVATED') {
            $errors = 'Your account is not activated. A confirmation email was sent to '.$email;
        }

        $domain = isset($result['domain_name']) ? $result['domain_name'] : '';
        $js_api = isset($result['api_key']['js_API_Key']) ? $result['api_key']['js_API_Key'] : '';
        $rest_api = isset($result['api_key']['rest_API_Key']) ? $result['api_key']['rest_API_Key'] : '';

        if ($rest_api != '') {
            engagebay_enable_livechat_widget($rest_api);
        }

        if ($domain == '' && $rest_api == '' && !isset($errors)) {
            $errors = 'Invalid details. Please provide valid details and try again';
        } elseif (!isset($errors)) {
            if (get_option('engagebay_livechat_password') !== false) {
                update_option('engagebay_livechat_password', $password);
            } else {
                add_option('engagebay_livechat_password', $password, $deprecated, $autoload);
            }

            if (get_option('engagebay_livechat_rest_api') !== false) {
                update_option('engagebay_livechat_rest_api', $rest_api);
            } else {
                add_option('engagebay_livechat_rest_api', $rest_api, $deprecated, $autoload);
            }

            if (get_option('engagebay_livechat_domain') !== false) {
                update_option('engagebay_livechat_domain', $domain);
            } else {
                add_option('engagebay_livechat_domain', $domain, $deprecated, $autoload);
            }

            if (get_option('engagebay_livechat_js_api') !== false) {
                update_option('engagebay_livechat_js_api', $js_api);
            } else {
                add_option('engagebay_livechat_js_api', $js_api, $deprecated, $autoload);
            }

            if (get_option('engagebay_livechat_email') !== false) {
                update_option('engagebay_livechat_email', $email);
            } else {
                add_option('engagebay_livechat_email', $email, $deprecated, $autoload);
            }

            $sucesserrors = 'SucessFully Verified the domain';
        }
    }
    $rest_api = (sanitize_text_field(get_option('engagebay_livechat_rest_api')));
    $domain = (sanitize_text_field(get_option('engagebay_livechat_domain')));
    $email = (sanitize_email(get_option('engagebay_livechat_email')));
    if (isset($_GET['edit'])) {
        $edit = $_GET['edit'];
    } ?>
  <div class="be-wrapper be-login">
    <div class="be-content">
      <div class="main-content container-fluid">
      <?php if ($email == '' || (isset($edit) && $edit == 'domain') || $rest_api == '') {
        ?>
      
        <div class="splash-container">
          <div class="panel">
            <?php if (isset($errors)) {
            echo '<div id="error_message">'.$errors.'<br/></div>';
        } ?>
            <?php if (isset($sucesserrors)) {
            echo '<div id="success_message">'.$sucesserrors.'<br/></div>';
        } ?>
            <div class="panel-heading text-center">
            <?php echo "<img src='".plugins_url('/images/engagebay.png', __FILE__)."' width='170' title='Enage bay logo'/>"; ?> 
              <h4>EngageBay Login</h4>
            </div>
            <div class="panel-body">
              <form name="loginForm" id="loginForm" class="" action="" method="post">
                <?php wp_nonce_field('engagebay_livechat_nonce_action', 'engagebay_livechat_nonce_field'); ?>
                <div class="form-group">
                  <div class="">
                    <input class="form-control" type="email" pattern="[a-z0-9._%+-]+@[a-z0-9.-]+\.[a-z]{2,10}$" name="email" autocomplete="off" placeholder="Work Email" value="<?php echo $email; ?>" required>
                  </div>
                </div>
                <div class="form-group">
                  <div class="">
                    <input class="form-control" type="password" name="password"  placeholder="Password" required>
                  </div>
                </div>
                <div class="form-group">
                  <div class="xs-pt-20 md-pt-20">
                    <div class="login-submit xs-m-0 md-p-0">
                      <button class="btn btn-success btn-xl" type="submit">LOGIN
                        <?php echo "<img src='".plugins_url('/images/loader.gif', __FILE__)."' 
                       style='display: none;' id='gif' title='Landing Pages'/>"; ?>
                    </div><br/>
                    <div class="btn btn-success btn-xl gsuite-btn-div">
                      <a><img class="gsuite-img" src="https://d2p078bqz5urf7.cloudfront.net/cloud/dev/assets/img/google-favicon.png"/></a>
                      <a class="gsuite-btn-text" href="https://app.engagebay.com/oauth?wordpressPlugin=yes&wordpressPluginURL=<?php echo admin_url('admin.php?page=engage-bay-livechat');?>">SIGN IN WITH G SUITE</a>
                    </div>
                  </div>
                </div>
                
              </form>
             <?php
engagebay_livechat_custom_js(); ?>
      </div>
          </div>
         <?php if ($email == '') {
            ?>
<div class="splash-footer">
            Forgot <a href="https://app.engagebay.com/forgot-password" target="_blank" class="text-info">Password?</a>
          </div>
  <div class="alert text-center">
              <div>
                  <!-- <div>Don't have an account? <a href="?page=engage-bay&tab=register" ><?php _e('Sign Up', 'sandbox'); ?></a> -->
                  <div>Don't have an account? <a href="https://app.engagebay.com/signup" target="_blank"><?php _e('Sign Up', 'sandbox'); ?></a></div>
               </div> 
   </div>

<?php
        } ?>
        </div>
        </div>

<?php
    } else {
        wp_redirect(engagebay_livechat_options_page());
    } ?>
  </div>
</div>
</div>
<?php
}

function engagebay_livechat_registration_page()
{
    if (!current_user_can('install_plugins') && !current_user_can('install_plugins')) {
        return;
    }
    $siteurl = (esc_url(get_option('siteurl')));
    $siteurl_parts = explode('/', $siteurl, 4);
    $base_siteurl = $siteurl_parts[0].'//'.$siteurl_parts[2];
    engagebay_livechat_css();
    $deprecated = null;
    $autoload = 'no';
    if (isset($_POST['email'])) {
        $email = sanitize_email($_POST['email']);
    }

    if (isset($email) && check_admin_referer('engagebay_livechat_nonce_action', 'engagebay_livechat_nonce_field')) {
        $engagebay_livechat_array['email'] = sanitize_email($_POST['email']);
        $engagebay_livechat_array['name'] = sanitize_text_field($_POST['name']);
        $engagebay_livechat_array['website'] = sanitize_text_field($_POST['website']);
        $engagebay_livechat_array['password'] = sanitize_text_field($_POST['password']);
        $engagebay_livechat_array['command'] = sanitize_text_field($_POST['command']);
        $engagebay_livechat_array['timeZoneId'] = sanitize_text_field($_POST['timeZoneId']);
        $engagebay_livechat_array['source'] = 'WORDPRESS';
        //$engagebay_livechat_json = json_encode($engagebay_livechat_array);
        $api_url = 'https://app.engagebay.com/rest/api/signup/signup-user';
        $request = wp_remote_post($api_url, array(
        'method' => 'post',
        'timeout' => 40,
        'httpversion' => '1.0',
        'blocking' => true,
        'body' => $engagebay_livechat_array,
        'headers' => array('ebwhitelist' => true)
          )
    );
        $result = wp_remote_retrieve_body($request);
        $resultString = $result;

        if (version_compare(PHP_VERSION, '5.4.0', '>=') && !(defined('JSON_C_VERSION') && PHP_INT_SIZE > 4)) {
            $result = json_decode($result, true, 512, JSON_BIGINT_AS_STRING);
        } else {
            $result = json_decode($result, true);
        }

        $domain = $result['domain_name'];
        $js_api = $result['api_key']['js_API_Key'];
        $rest_api = $result['api_key']['rest_API_Key'];
        if ($rest_api != '') {
            engagebay_enable_livechat_widget($rest_api);
        }

        $email = sanitize_email($_POST['email']);
        $password = sanitize_text_field($_POST['password']);
        if ($domain == '') {
            $errors = $resultString;
        } else {
            if (get_option('engagebay_livechat_password') !== false) {
                update_option('engagebay_livechat_password', $password);
            } else {
                add_option('engagebay_livechat_password', $password, $deprecated, $autoload);
            }

            if (get_option('engagebay_livechat_rest_api') !== false) {
                update_option('engagebay_livechat_rest_api', $rest_api);
            } else {
                add_option('engagebay_livechat_rest_api', $rest_api, $deprecated, $autoload);
            }

            if (get_option('engagebay_livechat_domain') !== false) {
                update_option('engagebay_livechat_domain', $domain);
            } else {
                add_option('engagebay_livechat_domain', $domain, $deprecated, $autoload);
            }

            if (get_option('engagebay_livechat_js_api') !== false) {
                update_option('engagebay_livechat_js_api', $js_api);
            } else {
                add_option('engagebay_livechat_js_api', $js_api, $deprecated, $autoload);
            }

            if (get_option('engagebay_livechat_email') !== false) {
                update_option('engagebay_livechat_email', $email);
            } else {
                add_option('engagebay_livechat_email', $email, $deprecated, $autoload);
            }

            $sucesserrors = 'SucessFully Registered';
        }
    } ?>
<div class="be-wrapper be-login">
    <div class="be-content">
      <div class="main-content container-fluid">
        <div class="splash-container">
          <div class="panel">
            <div class="panel-heading">
              
              <?php echo "<img src='".plugins_url('/images/engagebay.png', __FILE__)."' width='170' title='Enage bay logo'/>"; ?> 
              <h4>
                Get Started for <strong>FREE</strong>
              </h4>
            </div>
           <?php if (!isset($sucesserrors)) {
        ?>
              <div class="panel-body">
             <?php
              if (isset($errors)) {
                  ?>
                 <div class="alert alert-danger">
                  <strong><?php echo $errors; ?> </strong>
                  <?php echo $result; ?>
                </div>
             <?php
              } ?>
              <form id="loginForm" name="loginForm" method="POST">
                <?php wp_nonce_field('engagebay_livechat_nonce_action', 'engagebay_livechat_nonce_field'); ?>
                <input type="hidden" name="command" value="signup">
                <input type="hidden" name="timeZoneId" value="330">
                <input type="hidden" name="referral_user_id" value="">
                <div class="form-group">
                  <div class="">
                    <input class="form-control" type="name" name="name" autocomplete="name" placeholder="Name" title="Name should be between 1-30 characters in length. Both letters and numbers are allowed but it should start with a letter. Cannot contain special characters." minlength="1" maxlength="30" required="" pattern="^[a-zA-Z][a-zA-Z0-9 ]{1,30}$">
                  </div>
                </div>
                <div class="form-group">
                  <div class="position-relative">
                    <input class="form-control user-email-field" id="register_email" type="email" name="email" required autocapitalize="off" minlength="6" maxlength="50" placeholder="Work Email" oninvalid="set_custom_validate(this);" oninput="reset_custom_validate(this);"  pattern="^.+@((?!gmail.com)(?!yahoo.com)(?!yahoo.in)(?!hotmail.com)(?!fastmail.com).)+\..+$" data-pattern-mismatch-error="Please use your business email address to sign up" value="">
                    <span id="validEmail" class="validation-result">
                    </span>
                  </div>
                </div>                
                <div class="form-group">
                  <div class="">
                    <input class="form-control" type="url" name="website" autocomplete="url" placeholder="Website URL" value="<?php echo $base_siteurl; ?>"  minlength="3" maxlength="50" required="" pattern="^(https?://)?([a-zA-Z0-9]([a-zA-Z0-9\-]{0,61}[a-zA-Z0-9])?\.)+[a-zA-Z]{2,6}$">
                  </div>
                </div>
                <div class="form-group">
                  <div class="">
                    <input class="form-control" type="password" name="password" pattern=".{4,20}" autocomplete="off" placeholder="Password" title="Enter at least 4 characters." required="">
                  </div>
                </div>
                <div class="form-group">
                  <div class="xs-pt-20 md-pt-20">
                    <div class="login-submit xs-m-0 md-p-0">
                      <button class="btn btn-success btn-xl" type="submit">
                        SIGN UP
                        <?php echo "<img src='".plugins_url('/images/loader.gif', __FILE__)."' 
                       style='display: none;' id='gif' title='Landing Pages'/>"; ?>
                      </button>
                    </div>
                  </div>
                </div>
              </form>
            </div>

          </div>
          <div class="splash-footer">
            Forgot <a href="https://app.engagebay.com/forgot-password" target="_blank" class="text-info">Password?</a>
          </div>
          <div class="splash-footer alert">
            Already have an account? <a href="?page=engage-bay-livechat"  ><?php _e('Sign In', 'sandbox'); ?></a>
          </div>
           <?php
    } else {
        ?>
            <div class="panel-body">
              <div class="alert alert-success fade in alert-dismissible">
                <strong>Successfully!</strong>  Registered.
            </div>
            </div>
          <?php
             engagebay_livechat_refresh();
    } ?>
          
        </div>
      </div>
    </div>
  </div>

<?php
}

// plugin deactivation
register_deactivation_hook(__FILE__, 'engagebay_livechat_deactivate');
function engagebay_livechat_deactivate()
{
    delete_option('engagebay_livechat_domain');
    delete_option('engagebay_livechat_rest_api');
    delete_option('engagebay_livechat_email');
    delete_option('engagebay_livechat_js_api');
    delete_option('engagebay_livechat_password');
    delete_option('engagebay_livechat_enabled');
}

add_action('admin_notices', 'engagebay_livechat_admin_notices');
function engagebay_livechat_admin_notices()
{
    $engagebay_livechat_email = get_option('engagebay_livechat_email');
    if ($engagebay_livechat_email == '') {
        if (isset($_GET['page']) && $_GET['page'] != 'engage-bay-livechat') {
            echo "<div class='updated'><p>Almost done! <a href='admin.php?page=engage-bay-livechat'>Enter your engagebay details </a> and you'll be ready to rock.</p></div>";
        }
    }
}

add_action('wp_dashboard_setup', 'engagebay_livechat_dashboard_setup_function');

function engagebay_livechat_dashboard_setup_function()
{
    add_meta_box('engagebay_livechat_dashboard_widget', 'EngageBay - LiveChat', 'engagebay_livechat_dashboard_widget_function', 'dashboard', 'side', 'high');
}

function engagebay_livechat_dashboard_widget_function()
{
    $domain = get_option('engagebay_livechat_domain');
    if ($domain == false) {
        $domain = 'app';
    }
    wp_enqueue_style('engagebay-forms', plugins_url('/css/page.css', __FILE__)); ?>
 <div class="stunning-header stunning-header-bg-violet index-stunning-header">
  <div class="container">
   <div class="xs-pt-20 text-center">
    <?php
      $user_info = get_userdata(1);
    $userloginname = $user_info->user_login;
    $nicename = $user_info->user_nicename; ?>
      <div class="font-size-20 board-pad-text">Hello <span class="text-capitalize"></span><?php echo ucfirst($nicename); ?></div>
      </div>
    <div class="board-pad-text1 font-size-18 xs-pt-10 text-center">What would you like to do today?</div>
    
      <div class="stunning-header-content">
        <div class="col-md-3">
        <div class="service-box">
                  <div class="panel-body">
                    <div id="features">
    <a href="https://<?=$domain; ?>.engagebay.com/#chats" id="boxm" target="_blank">
       <div class="box">
       <div class="right stripline">
       <div class="header"><?php echo "<img src='".plugins_url('/images/conversations.svg', __FILE__)."' width='100px' height='100px' title='Landing Pages'/>"; ?> 
       <h3 class="heading">Answer Chats</h3>
       </div>
       
     </div>
    </div> </a>

    <a href="https://<?=$domain; ?>.engagebay.com/#lc-widget-settings" id="boxm" target="_blank">
    <div class="box">
      <div class="right stripline">
        <div class="header">
		<?php echo "<img src='".plugins_url('/images/chat-widgets.svg', __FILE__)."' width='100px' height='100px' title='Chat Widgets'/>"; ?>
        <h3 class="heading">Chat Widget</h3>
        </div>
        
       </div> 
     </div></a>

    <a href="https://<?=$domain; ?>.engagebay.com/#lc-chat-forms/prechat" id="boxm" target="_blank">
    <div class="box">
      <div class="right stripline">
       <div class="header">
	   <?php echo "<img src='".plugins_url('/images/chat-forms.svg', __FILE__)."' width='100px' height='100px' title='Chat Forms'/>"; ?> 
       <h3 class="heading"> Chat Form</h3>
       </div>
       
      </div>
    </div></a>
  
    <a href="https://<?=$domain; ?>.engagebay.com/#lc-shortcuts" id="boxm" target="_blank">
      <div class="box">
       <div class="right stripline">
        <div class="header"><?php echo "<img src='".plugins_url('/images/shortcuts.svg', __FILE__)."' width='100px' height='100px' title='Reports'/>"; ?> 
            <h3 class="heading">Shortcuts</h3>
         </div>

       </div>
    </div> </a>
    <a href="https://<?=$domain; ?>.engagebay.com/#lc-sound-settings" id="boxm" target="_blank">
       <div class="box">
       <div class="right stripline">
       <div class="header"><?php echo "<img src='".plugins_url('/images/settings.svg', __FILE__)."' width='100px' height='100px' title='Landing Pages'/>"; ?> 
       <h3 class="heading">Settings</h3>
       </div>
       
     </div>
    </div> </a>
    <a href="https://<?=$domain; ?>.engagebay.com/#livechat" id="boxm" target="_blank">
       <div class="box">
       <div class="right stripline">
       <div class="header"><?php echo "<img src='".plugins_url('/images/reports.svg', __FILE__)."' width='100px' height='100px' title='Landing Pages'/>"; ?> 
       <h3 class="heading">Reports</h3>
       </div>
       
     </div>
    </div> </a>

    </div>
        </div>
     </div>
  </div>
  </div>
 </div>
</div>
<?php
}

add_action('wp_enqueue_scripts', 'engagebay_livechat_refresh');

function engagebay_livechat_refresh()
{
    if (isset($_POST['name'])) {
        wp_enqueue_script('engagebay_livechat_refresh', plugins_url('js/refresh.js', __FILE__));
    }
}

add_action('admin_enqueue_scripts', 'engagebay_livechat_customjs');
function engagebay_livechat_customjs()
{
    wp_enqueue_script('customjs', plugins_url('/js/custom.js', __FILE__), array('jquery'));
}

function engagebay_livechat_footer()
{
    $rest_api = (sanitize_text_field(get_option('engagebay_livechat_rest_api')));
    $domain = (sanitize_text_field(get_option('engagebay_livechat_domain')));
    $email = (sanitize_email(get_option('engagebay_livechat_email')));
    $js_api = (sanitize_text_field(get_option('engagebay_livechat_js_api')));
    if ($js_api) {
        wp_enqueue_script('main-js', 'https://www.engagebay.com', array('jquery'));
        wp_register_script('tracking-js', plugin_dir_url(__FILE__).'js/tracking.js');
        wp_enqueue_script('tracking-js');
        wp_localize_script('tracking-js', 'engagebay_vars', array(
          'js_api' => $js_api,
          'domain' => $domain,
        ));
    }
}

add_action('wp_footer', 'engagebay_livechat_footer');

function engagebay_enable_livechat_widget($rest_api)
{
    $engagebay_rest_url = 'https://app.engagebay.com/dev/api/panel/livechat/settings/enable-chat-widget';
    $headers = array(
                        'Authorization' => $rest_api,
                        'Content-type' => 'application/json',
                        'Accept' => 'application/json',
                        'ebwhitelist' => true
                        );
    $args_post = array(
                          'method' => 'POST',
                          'timeout' => 120,
                          'sslverify' => false,
                          'headers' => $headers,
                          'body' => '',
                           );
    $result = wp_remote_post($engagebay_rest_url, $args_post);
    $result = wp_remote_retrieve_body($result);

    if (!is_wp_error($result)) {
        if (version_compare(PHP_VERSION, '5.4.0', '>=') && !(defined('JSON_C_VERSION') && PHP_INT_SIZE > 4)) {
            $result = json_decode($result, true, 512, JSON_BIGINT_AS_STRING);
        } else {
            $result = json_decode($result, true);
        }
    }

    if (isset($result['chatEnabled'])) {
        if (get_option('engagebay_livechat_enabled') !== false) {
            update_option('engagebay_livechat_enabled', $result['chatEnabled']);
        } else {
            add_option('engagebay_livechat_enabled', $result['chatEnabled']);
        }
    }
}

?>
